#!/bin/bash
#deploy OpenAttestation 2.x

source oat_function
### configuration ###
mysql_password=${mysql_password:-""}
oat_server=${oat_server:-""}
saml_password=${saml_password:-samlpasswd2}
portal_password=${portal_password:-portalpasswd2}
p12_password=${p12_password:-p12passwd2}
log_dir=${log_dir:-/var/log/tomcat}

if [ $# -lt 3 ]; then
    example
    exit 1
fi

while [ $# -gt 1 ]; do
  case $1 in
    --mysql)
        if [ "$2" != "--ip" ];then
            mysql_password=$2
            shift 2
        else
            shift 1
        fi
        ;;
    --ip)
        oat_server=$2
        shift 2
        ;;
    *)
        example
        exit 1;;
  esac
done

echo "oat_server = $oat_server"
echo "mysql_password = $mysql_password"

if [ "$oat_server" == "" ]; then
    example
    exit 1
fi

_oat_webapp=${_oat_webapp:-/usr/share/oat-appraiser/webapps}
_tomcat_webapp=${_tomcat_webapp:-/usr/share/tomcat/webapps}
## link lib
link_lib()
{
    curdir=`pwd`
    mkdir -p  $1/lib
    cd $1/lib
    linkjar
    cd $curdir
}

link_lib "$_oat_webapp/WLMService/WEB-INF"
link_lib "$_oat_webapp/WhiteListPortal/WEB-INF"
link_lib "$_oat_webapp/HisPrivacyCAWebServices2/WEB-INF"
link_lib "$_oat_webapp/TrustDashBoard/WEB-INF"
link_lib "$_oat_webapp/AttestationService/WEB-INF"

## link these projects to tomcat
lns()
{
    curdir=`pwd`
    cd $2 && ln -sf $1 .
    cd $curdir
}

lns "$_oat_webapp/AttestationService" "$_tomcat_webapp"
lns "$_oat_webapp/HisPrivacyCAWebServices2" "$_tomcat_webapp"
lns "$_oat_webapp/TrustDashBoard" "$_tomcat_webapp"
lns "$_oat_webapp/WhiteListPortal" "$_tomcat_webapp"
lns "$_oat_webapp/WLMService" "$_tomcat_webapp"

###########
conf_dir=${conf_dir:-/etc/intel/cloudsecurity}
chown -R tomcat:tomcat $conf_dir

tomcat_dir=${tomcat_dir:-/usr/share/tomcat}
###MySQL ###
mysql_status="`netstat -vulntp |grep -i mysqld`"
if [ -n "$mysql_status" ];then
    echo "mysqld service is running .."
else
    echo "starting mysqld service .."
    service mysqld start
fi
if [ "$mysql_password" == "" ];then
    mysql -uroot -e 'create database mw_as';
    mysql -uroot mw_as < /usr/share/oat-appraiser/mtwilson.sql
else
    mysql -uroot -p$mysql_password -e 'create database mw_as';
    mysql -uroot -p$mysql_password mw_as < /usr/share/oat-appraiser/mtwilson.sql
fi

cd $conf_dir
mtwilson_properties
trust_properties
whitelist_properties
attestation_properties
privacyca_properties
privacyca_client_properties

aik_home_dir="`mktemp -d /var/lib/oat-appraiser/oat.XXXXXX | awk -F\. '{print $2}'`"
sed -i "s/OATAPPR_IP/$oat_server/g" $conf_dir/mtwilson.properties
sed -i "s/OATAPPR_IP/$oat_server/g" $conf_dir/attestation-service.properties
sed -i "s/OATAPPR_IP/$oat_server/g" $conf_dir/privacyca-client.properties
sed -i "s/MYSQL_PASSWD/$mysql_password/g" $conf_dir/mtwilson.properties
sed -i "s/PORTAL_PASSWD/$portal_password/g" $conf_dir/trust-dashboard.properties
sed -i "s/PORTAL_PASSWD/$portal_password/g" $conf_dir/whitelist-portal.properties
sed -i "s/SAML_KEYSTORE_PASSWD/$saml_password/g" $conf_dir/attestation-service.properties
sed -i "s/SAML_KEY_PASSWD/$saml_password/g" $conf_dir/attestation-service.properties
sed -i "s/AIK_VERIFY_HOME/$aik_home_dir/g" $conf_dir/attestation-service.properties
sed -i "s/PRIVACY_CA_PASSWD/$p12_password/g" $conf_dir/PrivacyCA.properties
sed -i "s/<Context>/<Context override=\"true\" allowLinking=\"true\">/g" $tomcat_dir/conf/context.xml

att_parse()
{
  cat $conf_dir/attestation-service.properties | \
      grep "$1" | awk -F= '{print $2}'
}

trust_tdb_parse()
{
  cat $conf_dir/trust-dashboard.properties | \
      grep "$1" | awk -F= '{print $2}'
}

saml_key_aslias="`att_parse "saml.key.aslias"`"
saml_keystore_file="`att_parse "saml.keystore.file"`"
saml_keystore_password="`att_parse "saml.keystore.password"`"
saml_key_password="`att_parse "saml.key.password"`"
server_keystore_password="`date  +%s%N`"
server_key_password=$server_keystore_password

### Create SAML Signing Key ###
keytool -genkey -alias $saml_key_aslias -keyalg RSA -keysize 2048 \
        -keystore $saml_keystore_file -storepass $saml_keystore_password \
        -dname "CN=AttestationService, OU=MtWilson, O=MyOrg, C=US" \
        -validity 3650 -keypass $saml_key_password

keytool -export -alias $saml_key_aslias -keystore $saml_keystore_file \
        -storepass $saml_keystore_password -file $conf_dir/saml.crt

### Create EK Signing Certificate ###
pushd $(pwd)
cd $log_dir
java -jar /usr/share/java/oat-appraiser/HisPrivacyCAWebServices2-setup.jar
popd
cp /var/lib/oat-appraiser/clientfiles/PrivacyCA.cer $conf_dir

### Create Attestation Server Certificate ###
privacyca_server="`att_parse "privacyca.server"`"
chown -R tomcat:tomcat $tomcat_dir/Certificate
chown -R tomcat:tomcat /var/lib/oat-appraiser/oat.$aik_home_dir

[ -e $tomcat_dir/Certificate/keystore.jks ] && \
     rm -f $tomcat_dir/Certificate/keystore.jks

[ -e $tomcat_dir/Certificate/ssl.${privacyca_server}.crt ] && \
     rm -f $tomcat_dir/Certificate/ssl.${privacyca_server}.crt

keytool -genkey -alias s1as -keyalg RSA -keysize 2048 \
        -keystore $conf_dir/keystore.jks -storepass $server_keystore_password \
        -dname "CN=$(hostname -f), OU=Mt Wilson, O=My Org, C=US" \
        -validity 3650 -ext san=IP:${privacyca_server} \
        -keypass $server_key_password

keytool -exportcert -alias s1as -keystore $conf_dir/keystore.jks \
        -storepass $server_keystore_password \
        -file $conf_dir/ssl.${privacyca_server}.crt

cp -f $conf_dir/keystore.jks $tomcat_dir/Certificate/
cp -f $conf_dir/ssl.${privacyca_server}.crt $tomcat_dir/Certificate/

### Create Portal Signing Key ###
tdbp_password="`trust_tdb_parse "mtwilson.tdbp.keystore.password"`"

keytool -genkey -alias admin -keyalg RSA -keysize 2048 -keystore $conf_dir/portal.jks \
        -storepass $tdbp_password "CN=Portal User, OU=Mt Wilson, O=My Org, C=US" \
        -validity 3650 -keypass $tdbp_password

keytool -importcert -file $conf_dir/saml.crt -keystore $conf_dir/portal.jks \
        -storepass $tdbp_password -alias "mtwilson (saml)"

keytool -importcert -file $conf_dir/ssl.${privacyca_server}.crt  \
        -keystore $conf_dir/portal.jks \
        -storepass $tdbp_password -alias "mtwilson (ssl)"

sed -i "/<\/Service>/i\    <Connector port=\"8181\" minSpareThreads=\"5\" maxSpareThreads=\"75\" enableLookups=\"false\" disableUploadTimeout=\"true\" acceptCount=\"100\" maxThreads=\"200\" scheme=\"https\" secure=\"true\" SSLEnabled=\"true\" clientAuth=\"want\" sslProtocol=\"TLS\" ciphers=\"TLS_ECDH_anon_WITH_AES_256_CBC_SHA, TLS_ECDH_anon_WITH_AES_128_CBC_SHA, TLS_ECDH_anon_WITH_3DES_EDE_CBC_SHA, TLS_ECDH_RSA_WITH_AES_256_CBC_SHA, TLS_ECDH_RSA_WITH_AES_128_CBC_SHA, TLS_ECDH_RSA_WITH_3DES_EDE_CBC_SHA, TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA, TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA, TLS_ECDHE_ECDSA_WITH_3DES_EDE_CBC_SHA, TLS_ECDH_ECDSA_WITH_AES_256_CBC_SHA, TLS_ECDH_ECDSA_WITH_AES_128_CBC_SHA, TLS_ECDH_ECDSA_WITH_3DES_EDE_CBC_SHA, TLS_DHE_RSA_WITH_AES_256_CBC_SHA, TLS_DHE_DSS_WITH_AES_256_CBC_SHA, TLS_RSA_WITH_AES_256_CBC_SHA, TLS_DHE_RSA_WITH_AES_128_CBC_SHA, TLS_DHE_DSS_WITH_AES_128_CBC_SHA, TLS_RSA_WITH_AES_128_CBC_SHA\" keystoreFile=\"Certificate\/keystore.jks\" keystorePass=\"$server_keystore_password\" truststoreFile=\"Certificate\/keystore.jks\" truststorePass=\"$server_key_password\"\/>" $tomcat_dir/conf/server.xml

### tomcat6 restart ###
service tomcat restart

